@@ -1,12 +1,5 @@
-from .helpers import check_allow_for_user, check_allow_for_uri
+from .helpers import check_allow_for_user, check_allow_for_uri, User
 
-try:
-    # Django 1.5 check
-    from django.contrib.auth import get_user_model
-except ImportError:
-    from django.contrib.auth.models import User
-else:
-    User = get_user_model()
 
 class ImpersonateMiddleware(object):
     def process_request(self, request):
@@ -16,6 +9,10 @@ class ImpersonateMiddleware(object):
         if request.user.is_authenticated() and \
            '_impersonate' in request.session:
             new_user_id = request.session['_impersonate']
+            if isinstance(new_user_id, User):
+                # Edge case for issue 15
+                new_user_id = new_user_id.id
+
             try:
                 new_user = User.objects.get(id=new_user_id)
             except User.DoesNotExist:
