@@ -123,11 +123,11 @@ class TestMiddleware(TestCase):
         self.factory = RequestFactory()
         self.middleware = ImpersonateMiddleware()
 
-    def test_impersonated_request(self):
+    def _impersonated_request(self, use_id=True):
         request = self.factory.get('/')
         request.user = self.superuser
         request.session = {
-            '_impersonate': self.user.id
+            '_impersonate': self.user.id if use_id else self.user,
         }
         self.middleware.process_request(request)
 
@@ -136,6 +136,15 @@ class TestMiddleware(TestCase):
         self.assertEqual(request.impersonator, self.superuser)
         self.assertTrue(request.user.is_impersonate)
 
+    def test_impersonated_request(self):
+        self._impersonated_request()
+
+    def test_impersonated_request_non_id(self):
+        ''' Test to ensure User objects don't kill the app.
+            See Issue #15
+        '''
+        self._impersonated_request(use_id=False)
+
 
 class TestImpersonation(TestCase):
 
@@ -354,6 +363,12 @@ class TestImpersonation(TestCase):
         )
         self.assertEqual(response.context['users'].count(), 1)
 
+        response = self.client.get(
+            reverse('impersonate-search'),
+            {'q': '   john   doe'},
+        )
+        self.assertEqual(response.context['users'].count(), 1)
+
         response = self.client.get(
             reverse('impersonate-search'),
             {'q': 'noresultsfound'},
@@ -369,6 +384,55 @@ class TestImpersonation(TestCase):
             self.assertEqual(response.context['users'].count(), 4)
         self.client.logout()
 
+    @override_settings(IMPERSONATE_SEARCH_FIELDS=['first_name', 'last_name'])
+    def test_user_search_custom_fields(self):
+        self.client.login(username='user1', password='foobar')
+        response = self.client.get(
+            reverse('impersonate-search'),
+            {'q': 'john'},
+        )
+        self.assertEqual(response.context['users'].count(), 2)
+
+        response = self.client.get(
+            reverse('impersonate-search'),
+            {'q': 'doe'},
+        )
+        self.assertEqual(response.context['users'].count(), 1)
+
+        response = self.client.get(
+            reverse('impersonate-search'),
+            {'q': 'user'},
+        )
+        self.assertEqual(response.context['users'].count(), 0)
+        self.client.logout()
+
+    @override_settings(IMPERSONATE_LOOKUP_TYPE='exact')
+    def test_user_search_custom_lookup(self):
+        self.client.login(username='user1', password='foobar')
+        response = self.client.get(
+            reverse('impersonate-search'),
+            {'q': 'John'},
+        )
+        self.assertEqual(response.context['users'].count(), 2)
+
+        response = self.client.get(
+            reverse('impersonate-search'),
+            {'q': 'Doe'},
+        )
+        self.assertEqual(response.context['users'].count(), 1)
+
+        response = self.client.get(
+            reverse('impersonate-search'),
+            {'q': 'john'},
+        )
+        self.assertEqual(response.context['users'].count(), 0)
+
+        response = self.client.get(
+            reverse('impersonate-search'),
+            {'q': 'doe'},
+        )
+        self.assertEqual(response.context['users'].count(), 0)
+
     @override_settings(IMPERSONATE_REDIRECT_FIELD_NAME='next')
     def test_redirect_field_name(self):
         self.client.login(username='user1', password='foobar')
